@@ -484,11 +484,11 @@ if __name__=="__main__":
     import sys
 
     dispatcher = SoapDispatcher(
-        name = "PySimpleSoapSample",
+        name = "py3simplesoapSample",
         location = "http://localhost:8008/",
         action = 'http://localhost:8008/', # SOAPAction
-        namespace = "http://example.com/pysimplesoapsamle/", prefix="ns0",
-        documentation = 'Example soap service using PySimpleSoap',
+        namespace = "http://example.com/py3simplesoapsamle/", prefix="ns0",
+        documentation = 'Example soap service using py3simplesoap',
         trace = True,
         ns = True)
     
